@@ -7,7 +7,7 @@ from functools import wraps
 
 from github import Github, GithubException
 
-DEFAULT_WORK_BRANCH = "ghworkspace"
+WORK_BRANCH = "ghworkspace"
 DEFAULT_BASE_BRANCH = "master"
 
 
@@ -74,12 +74,7 @@ def workspace(func):
             if not name:
                 raise InputParameterError("Missing `name` parameter.")
 
-        work_branch = kwargs.get("work_branch", None)
-        if not work_branch:
-            work_branch = args[3] if len(args) > 3 else None
-            if not work_branch:
-                work_branch = DEFAULT_WORK_BRANCH
-
+        work_branch = kwargs["work_branch"] if "work_branch" in kwargs else WORK_BRANCH
         base_branch = kwargs["base_branch"] if "base_branch" in kwargs else DEFAULT_BASE_BRANCH
 
         # Preparing for Work branch
